# The base of the version (just major and minor without point)
%global base_version 2.4

Name:           libodb-sqlite
Version:        %{base_version}.0
Release:        9%{?dist}
Summary:        SQLite ODB runtime library from Code Synthesis

Group:          System Environment/Libraries
License:        GPLv2
URL:            http://www.codesynthesis.com/products/odb/
Source0:        http://www.codesynthesis.com/download/odb/%{base_version}/%{name}-%{version}.tar.bz2

# Set BuildRoot for compatibility with EPEL <= 5
# See: http://fedoraproject.org/wiki/EPEL:Packaging#BuildRoot_tag
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Uses libodb from Code Synthesis 
BuildRequires: libodb-devel >= %{base_version}
# Uses SQLite
BuildRequires: sqlite-devel
# Uses pkgconfig
BuildRequires: pkgconfig


%description
ODB is an object-relational mapping (ORM) system for C++. It provides
tools, APIs, and library support that allow you to persist C++ objects
to a relational database (RDBMS) without having to deal with tables,
columns, or SQL and without manually writing any of the mapping code.

This package contains the SQLite ODB runtime library. Every application
that includes code generated for the SQLite database will need to link
to this library.


%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries
Requires:       %{name}%{?_isa} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.


%prep
%setup -q


%build
# If building on Fedora or RHEL 7
%if 0%{?rhel}%{?fedora} >= 7
%configure --disable-static
%else
# Disable multi-threaded access on RHEL 5/6 because sqlite isn't built with the
# necessary flags to support it
# See: http://www.codesynthesis.com/pipermail/odb-users/2013-February/001065.html
%configure --disable-static --disable-threads
%endif
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT
find $RPM_BUILD_ROOT -name '*.la' -exec rm -f {} ';'


%clean
rm -rf $RPM_BUILD_ROOT


%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig


%files
%doc GPLv2
%doc LICENSE
%{_libdir}/libodb-sqlite-%{base_version}.so
%exclude %{_datadir}/doc/libodb-sqlite/GPLv2
%exclude %{_datadir}/doc/libodb-sqlite/LICENSE
%exclude %{_datadir}/doc/libodb-sqlite/NEWS
%exclude %{_datadir}/doc/libodb-sqlite/README
%exclude %{_datadir}/doc/libodb-sqlite/version

%files devel
%doc NEWS
# odb folder is created/owned by libodb package
%{_includedir}/odb/*
%{_libdir}/libodb-sqlite.so
%{_libdir}/pkgconfig/libodb-sqlite.pc


%changelog
* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 2.4.0-3
- Rebuilt for GCC 5 C++11 ABI change

* Mon Feb 16 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-2
- Rebuild for gcc 5.0 C++ ABI change

* Wed Feb 11 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-1
- Updated to 2.4.0

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Nov 4 2013 Dave Johansen <davejohansen@gmail.com> 2.3.0-1
- Updated to 2.3.0

* Sat Oct 5 2013 Dave Johansen <davejohansen@gmail.com> 2.2.3-1
- Initial build
